==> ejc-ztpcdc-impl-3.0.0-20230608.013305-63-sources.jar: com/ejianc/business/dc/vo/DcChangemanageInfoVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.dc.vo.DcChangemanageDrawinfoVO;
import com.ejianc.business.dc.vo.DcChangemanageInfoVO;

/**
 * 变更管理表
 * 
 * @author generator
 * 
 */
public class DcChangemanageInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据状态
    private String fileCode; // 文件编码
    private String fileName; // 文件名称
    private String fileVsn; // 版本
    private Long changeType; // 文件类型（自定义档案需要分项目（CR，FCR,DEN,TA,FCO））
    private Date arriveDate; // 收文日期
    private Long mgrp; // 机组--字典pub_mgrp_code
    private Long specialty; // 专业--字典pub_specialty_code
    private String fileAttachment; // 文件附件
    private String isContractScope; // 是否合同范围（Y是/N否）
    private String isEntity; // 是否为实体类（Y是/N否）
    private String isMaterialChange; // 是否涉及材料变更（Y是/N否）
    private String isDrawquantityChange; // 是否变更图纸工程量（Y是/N否）
    private String isClaim; // 是否涉及索赔（Y是/N否）
    private String claimFileCode; // 索赔文件编号
    private String isClose; // 是否验证关闭
    private String closeFileCode; // 关闭文件编号
    private String dutyUserName; // 责任人
    private Long createDeptId; // 创建部门id
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    
    private List<DcChangemanageDrawinfoVO> dcChangemanageDrawinfoList = new ArrayList<>(); // 变更管理受影响图纸信息表

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileVsn() {
        return fileVsn;
    }

    public void setFileVsn(String fileVsn) {
        this.fileVsn = fileVsn;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getChangeType() {
        return changeType;
    }
    @ReferDeserialTransfer
    public void setChangeType(Long changeType) {
        this.changeType = changeType;
    }
    public Date getArriveDate() {
        return arriveDate;
    }

    public void setArriveDate(Date arriveDate) {
        this.arriveDate = arriveDate;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMgrp() {
        return mgrp;
    }
    @ReferDeserialTransfer
    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSpecialty() {
        return specialty;
    }
    @ReferDeserialTransfer
    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }
    public String getFileAttachment() {
        return fileAttachment;
    }

    public void setFileAttachment(String fileAttachment) {
        this.fileAttachment = fileAttachment;
    }
    public String getIsContractScope() {
        return isContractScope;
    }

    public void setIsContractScope(String isContractScope) {
        this.isContractScope = isContractScope;
    }
    public String getIsEntity() {
        return isEntity;
    }

    public void setIsEntity(String isEntity) {
        this.isEntity = isEntity;
    }
    public String getIsMaterialChange() {
        return isMaterialChange;
    }

    public void setIsMaterialChange(String isMaterialChange) {
        this.isMaterialChange = isMaterialChange;
    }
    public String getIsDrawquantityChange() {
        return isDrawquantityChange;
    }

    public void setIsDrawquantityChange(String isDrawquantityChange) {
        this.isDrawquantityChange = isDrawquantityChange;
    }
    public String getIsClaim() {
        return isClaim;
    }

    public void setIsClaim(String isClaim) {
        this.isClaim = isClaim;
    }
    public String getClaimFileCode() {
        return claimFileCode;
    }

    public void setClaimFileCode(String claimFileCode) {
        this.claimFileCode = claimFileCode;
    }
    public String getIsClose() {
        return isClose;
    }

    public void setIsClose(String isClose) {
        this.isClose = isClose;
    }
    public String getCloseFileCode() {
        return closeFileCode;
    }

    public void setCloseFileCode(String closeFileCode) {
        this.closeFileCode = closeFileCode;
    }
    public String getDutyUserName() {
        return dutyUserName;
    }

    public void setDutyUserName(String dutyUserName) {
        this.dutyUserName = dutyUserName;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getCreateDeptId() {
        return createDeptId;
    }
    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }
    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    
     public List<DcChangemanageDrawinfoVO> getDcChangemanageDrawinfoList() {
        return dcChangemanageDrawinfoList;
     }

     public void setDcChangemanageDrawinfoList(List<DcChangemanageDrawinfoVO> dcChangemanageDrawinfoList) {
        this.dcChangemanageDrawinfoList = dcChangemanageDrawinfoList;
     }
}

==> ejc-ztpcdc-impl-3.0.0-20230731.064156-148-sources.jar: com/ejianc/business/dc/vo/DcChangemanageInfoVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.dc.vo.DcChangemanageDrawinfoVO;
import com.ejianc.business.dc.vo.DcChangemanageInfoVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 变更管理表
 * 
 * @author generator
 * 
 */
public class DcChangemanageInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据状态
    private String fileCode; // 文件编码
    private String fileName; // 文件名称
    private String fileVsn; // 版本
    private Long changeType; // 文件类型（自定义档案需要分项目（CR，FCR,DEN,TA,FCO））
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date arriveDate; // 收文日期
    private Long mgrp; // 机组--字典pub_mgrp_code
    private Long specialty; // 专业--字典pub_specialty_code
    private String fileAttachment; // 文件附件
    private Boolean contractScope; // 是否合同范围（Y是/N否）
    private Boolean entity; // 是否为实体类（Y是/N否）
    private Boolean materialChange; // 是否涉及材料变更（Y是/N否）
    private Boolean drawquantityChange; // 是否变更图纸工程量（Y是/N否）
    private Boolean claim; // 是否涉及索赔（Y是/N否）
    private String claimFileCode; // 索赔文件编号
    private Boolean close; // 是否验证关闭
    private String closeFileCode; // 关闭文件编号
    private String dutyUserName; // 责任人
    private Long createDeptId; // 创建部门id
    private Long projectId; // 项目ID
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Long orgId; // 所属组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    
    private List<DcChangemanageDrawinfoVO> dcChangemanageDrawinfoList = new ArrayList<>(); // 变更管理受影响图纸信息表

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileVsn() {
        return fileVsn;
    }

    public void setFileVsn(String fileVsn) {
        this.fileVsn = fileVsn;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getChangeType() {
        return changeType;
    }
    @ReferDeserialTransfer
    public void setChangeType(Long changeType) {
        this.changeType = changeType;
    }
    public Date getArriveDate() {
        return arriveDate;
    }

    public void setArriveDate(Date arriveDate) {
        this.arriveDate = arriveDate;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getMgrp() {
        return mgrp;
    }
    @ReferDeserialTransfer
    public void setMgrp(Long mgrp) {
        this.mgrp = mgrp;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getSpecialty() {
        return specialty;
    }
    @ReferDeserialTransfer
    public void setSpecialty(Long specialty) {
        this.specialty = specialty;
    }




    public String getCloseFileCode() {
        return closeFileCode;
    }

    public void setCloseFileCode(String closeFileCode) {
        this.closeFileCode = closeFileCode;
    }
    public String getDutyUserName() {
        return dutyUserName;
    }

    public String getFileAttachment() {
        return fileAttachment;
    }

    public void setFileAttachment(String fileAttachment) {
        this.fileAttachment = fileAttachment;
    }

    public Boolean getContractScope() {
        return contractScope;
    }

    public void setContractScope(Boolean contractScope) {
        this.contractScope = contractScope;
    }

    public Boolean getEntity() {
        return entity;
    }

    public void setEntity(Boolean entity) {
        this.entity = entity;
    }

    public Boolean getMaterialChange() {
        return materialChange;
    }

    public void setMaterialChange(Boolean materialChange) {
        this.materialChange = materialChange;
    }

    public Boolean getDrawquantityChange() {
        return drawquantityChange;
    }

    public void setDrawquantityChange(Boolean drawquantityChange) {
        this.drawquantityChange = drawquantityChange;
    }

    public Boolean getClaim() {
        return claim;
    }

    public void setClaim(Boolean claim) {
        this.claim = claim;
    }

    public Boolean getClose() {
        return close;
    }

    public void setClose(Boolean close) {
        this.close = close;
    }

    public String getClaimFileCode() {
        return claimFileCode;
    }

    public void setClaimFileCode(String claimFileCode) {
        this.claimFileCode = claimFileCode;
    }

    public void setDutyUserName(String dutyUserName) {
        this.dutyUserName = dutyUserName;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getCreateDeptId() {
        return createDeptId;
    }
    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getParentOrgId() {
        return parentOrgId;
    }
    @ReferDeserialTransfer
    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    
     public List<DcChangemanageDrawinfoVO> getDcChangemanageDrawinfoList() {
        return dcChangemanageDrawinfoList;
     }

     public void setDcChangemanageDrawinfoList(List<DcChangemanageDrawinfoVO> dcChangemanageDrawinfoList) {
        this.dcChangemanageDrawinfoList = dcChangemanageDrawinfoList;
     }
}
